@@ -26,7 +26,13 @@
 #include <fcntl.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include <sys/soundcard.h>
+
+#ifdef __OpenBSD__
+# include <soundcard.h>
+#else
+# include <sys/soundcard.h>
+#endif
+
 #include <sys/ioctl.h>
 #include <errno.h>
 #include <curses.h>
