@@ -17,10 +17,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <curses.h>
 #include "tlf.h"
 #include "clear_display.h"
 #include "onechar.h"
@@ -60,6 +56,6 @@
 #include "rtty.h"
 
 
-int callinput(void);
+char callinput(void);
 int play_file(char *audiofile);
 
