@@ -35,11 +35,12 @@
 #include "muf.h"
 #include "parse_logcfg.h"
 #ifdef HAVE_LIBHAMLIB
-#include "rig.h"
+#include <hamlib/rig.h>
 #endif
 #include "gettxinfo.h"
 #include "netkeyer.h"
 #include "splitscreen.h"
+#include "audio.h"
 
 #define RITCLEAR 1
 
