@@ -21,8 +21,9 @@
 #include<stdlib.h>
 #include<unistd.h>
 #include "tlf.h"
+
 #ifdef HAVE_LIBHAMLIB
-#include "rig.h"
+#include <hamlib/rig.h>
 #endif
 
 #define SETCWMODE 1
