@@ -25,8 +25,9 @@
 #include "searchlog.h"
 
 #ifdef HAVE_LIBHAMLIB
-#include "rig.h"
+#include <hamlib/rig.h>
 #endif
 
-int grabspot (void);
+void grabspot (void);
+void grab_next (void);
 
