@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <curses.h>
+#include <pthread.h>
 #include "tlf.h"
 #include "scroll_log.h"
 #include "addcall.h"
@@ -32,6 +33,7 @@
 #endif
 #include "gettxinfo.h"
 #include "lancode.h"
+#include "addspot.h"
 
-int log_to_disk (void);
+int log_to_disk (int from_lan);
 
