@@ -16,10 +16,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <curses.h>
+
+#include "tlf.h"
 #include "clear_display.h"
 #include "printcall.h"
 #include "callinput.h"
@@ -29,10 +27,9 @@
 #include "log_to_disk.h"
 #include "keyer.h"
 #include "recall_exchange.h"
-#include "tlf.h"
 #include "sendqrg.h"
 #include "lancode.h"
 
 
 int logit(void);
-
+void refresh_comment(void);
