@@ -38,3 +38,8 @@
 #include "sendqrg.h"
 #include "netkeyer.h"
 #include "lancode.h"
+#include "rules.h"
+#include "startmsg.h"
+#include "rtty.h"
+#include "initial_exchange.h"
+#include "bandmap.h"
