@@ -27,9 +27,12 @@
 #define K_DEVICE 8
 #define K_TOD 9			// set txdelay (turn on delay)
 #define K_ADDRESS 10	// set port address of device
-#define K_SET14 11 		// set pin 14 on lpt0
+#define K_SET14 11 		// set pin 14 on lpt
 #define K_TUNE 12		// tune
 #define K_PTT 13		// PTT on/off
+#define K_SWITCH 14		// set band switch output pins 2,7,8,9 on lpt
+#define K_SIDETONE 15	// set sidetone to sound card
+#define K_STVOLUME 16	// set sidetone volume
 
 int netkeyer(int cw_op, char *cwmessage);
 int netkeyer_close(void);
