@@ -16,25 +16,34 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-   	/* ------------------------------------------------------------
- 	*      printcall
- 	*
- 	*--------------------------------------------------------------*/
+	/* ------------------------------------------------------------
+	 *      printcall
+	 *
+	 *--------------------------------------------------------------*/
 
-#include "printcall.h"	
-	
-	void printcall(void){
-	
-	extern int use_rxvt;
-	extern char hiscall[];
+#include "tlf.h"
+#include "printcall.h"
 
-	if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_BLUE) | A_STANDOUT |  A_BOLD);
-	else attron(COLOR_PAIR(COLOR_BLUE) | A_STANDOUT );
+void printcall(void)
+{
 
-	mvprintw(12, 29, "            ");
-	mvprintw(12, 29, hiscall);
-	refresh();
-    }
+    extern int use_rxvt;
+    extern char hiscall[];
+    extern int miniterm;
 
+    int currentterm;
 
+    currentterm = miniterm;
+    miniterm = 0;
 
+    if (use_rxvt == 0)
+	attron(COLOR_PAIR(COLOR_BLUE) | A_STANDOUT | A_BOLD);
+    else
+	attron(COLOR_PAIR(COLOR_BLUE) | A_STANDOUT);
+
+    mvprintw(12, 29, "            ");
+    mvprintw(12, 29, hiscall);
+    refreshp();
+
+    miniterm = currentterm;
+}
