@@ -17,6 +17,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "tlf.h"
+#include "sendbuf.h"
+#include "sendqrg.h"
 
 int speedup(void);
 int setweight(int weight);
