@@ -17,6 +17,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "tlf.h"
  #include "startmsg.h"
  #include <curses.h>
  #include <time.h>
@@ -31,7 +32,7 @@ extern int verbose;
  if (linectr == 24) linectr = 1;
 
  mvprintw(linectr, 0, message);
- refresh();
+ refreshp();
  if (verbose == 1) sleep(1);
  linectr++;
  }
@@ -44,7 +45,7 @@ extern int verbose;
  if (linectr == 24) linectr = 1;
 
  mvprintw(linectr, 0, "%s %d", message, nr);
- refresh();
+ refreshp();
  if (verbose == 1) sleep(1);
  linectr++;
  }
@@ -57,7 +58,7 @@ extern int verbose;
  if (linectr == 24) linectr = 1;
 
  mvprintw(linectr, 0, "%s %s", message1, message2);
- refresh();
+ refreshp();
  if (verbose == 1) sleep(1);
  linectr++;
  }
