@@ -21,56 +21,25 @@
  	*
  	*--------------------------------------------------------------*/
 
+#include "globalvars.h"
 #include "store_qso.h"
 
-int store_qso(void)
+int store_qso(char *loglineptr)
 {
-extern char logfile[26];
-extern char logline4[];
-extern char qsos[MAX_CALLS][82];
-extern int nr_qsos;
+	FILE *fp;
 
-FILE *fp;
-
-if  ( (fp = fopen(logfile,"a"))  == NULL){
+	if  ( (fp = fopen(logfile,"a"))  == NULL){
 		fprintf(stdout,  "store_qso.c: Error opening file.\n");
 		endwin();
 		exit(1);
 	}
-	strcpy(qsos[nr_qsos], logline4);
+	strcpy(qsos[nr_qsos], loglineptr);
 	nr_qsos++;
-	strcat(logline4, "\n");
-	fputs  (logline4, fp);
+	strcat(loglineptr, "\n");	// pa3fwm, 20040113: this looks suspicious, repeated calls to store_qso() could add multiple \n's
+	fputs  (loglineptr, fp);
 
+	fclose(fp);
 
-fclose(fp);
-
-return(0);
+	return(0);
 }
-/* --------------------- store for lan qso's ------------------*/
 
-int store_qso2(void)
-{
-extern char logfile[26];
-extern char lan_logline[];
-extern char qsos[MAX_CALLS][82];
-extern int nr_qsos;
-
-FILE *fp;
-
-if  ( (fp = fopen(logfile,"a"))  == NULL){
-		fprintf(stdout,  "store_qso.c: Error opening file.\n");
-		endwin();
-		exit(1);
-	}
-	strcpy(qsos[nr_qsos], lan_logline);
-	nr_qsos++;
-	strcat(lan_logline, "\n");
-	fputs  (lan_logline, fp);
-
-	lan_logline[0]='\0';
-
-fclose(fp);
-
-return(0);
-}
