@@ -29,9 +29,7 @@
 #include <sys/wait.h>
 #include <signal.h>
 
-#if defined (TLF_H)
-/* do nothing, already defined */
-#else
+#ifndef TLF_H
 #define TLF_H
 
 #ifdef HAVE_CONFIG_H
@@ -40,8 +38,8 @@
 
 
 #define NO_KEYER 0
-#define LPT_KEYER 1
-#define COM1_KEYER 2
+#define LPT_KEYER 1 	/* deprecated */
+#define COM1_KEYER 2	/* deprecated */
 #define NET_KEYER 3
 #define MFJ1278_KEYER 4
 #define ORION_KEYER 5
@@ -57,8 +55,7 @@
 #define FIFO_INTERFACE 4
 
 #define NOCLUSTER 0     /*  no cluster info  */
-#define MAP 1           /*  filter follows  band */
-#define SPOTS 2         /*  all spots */
+#define MAP 1           /*  show spots */
 #define CLUSTER 3 		/*  full cluster info  */
 #define FREQWINDOW 4    /* M/M frequencies */
 
@@ -70,11 +67,11 @@
 #define CQ 1			/* cqmode   on */
 #define S_P 0			/* S&P mode  on  */
 
-#define SEND_DE 1		/* demode on */
-#define CONTEST 1		/*  contest mode on */
+#define SEND_DE 1		/* de_mode on */
+#define CONTEST 1		/* contest mode on */
 
 #define FILTER_ANN 1	/*  filter announcements */
-#define FILTER_DX	 3
+#define FILTER_DX 3
 #define FILTER_ALL 0
 #define FILTER_TALK 2
 
@@ -89,40 +86,42 @@
 #define  BAND15 2
 #define  BAND10 1
 
-#define BANDINDEX_160 0
-#define BANDINDEX_80 1
-#define BANDINDEX_40 2
-#define BANDINDEX_30 3
-#define BANDINDEX_20 4
-#define BANDINDEX_17 5
-#define BANDINDEX_15 6
-#define BANDINDEX_12 7
-#define BANDINDEX_10 8
+enum {
+    BANDINDEX_160 = 0,
+    BANDINDEX_80,
+    BANDINDEX_40,
+    BANDINDEX_30,
+    BANDINDEX_20,
+    BANDINDEX_17,
+    BANDINDEX_15,
+    BANDINDEX_12,
+    BANDINDEX_10,
+    NBANDS 		// not yet used everywhere, 
+};			// many places have hardcode 9 
+			// (or 8, being the maximum band index)
+			//
+extern int inxes[NBANDS];  /*< conversion from BANDINDEX to BAND-mask,
+			see addmult.c */
 
-#define NBANDS 9	// not yet used everywhere, many places have hardcode 9 (or 8, being the maximum band index)
 
 #define DUPECOLOR 5
 #define NORMCOLOR 4
 #define ISDUPE 1
 #define NODUPE 0
 
-#define  MAX_QSOS 20000           /* internal qso array */
+#define  MAX_QSOS 20000       /* internal qso array */
 #define  MAX_DATALINES 1000   /* from ctydb.dat  */
-#define  MAX_DBLINES 6000    /* exceptioncalls from ctydb.dat  */
 #define  MAX_CALLS 5000      /*  max nr of calls in dupe array */
 #define  MAX_MULTS 1000        /* max nr of mults in mults array */
 #define	MAX_SPOTS 200		/* max nr. of spots in spotarray */
 #define MAX_CALLMASTER 50000 /* max number of calls in callmaster array */
 
-#define  MAX_COMMANDS 155
-
 #define EDITOR_JOE 0
 #define EDITOR_VI 1
 #define EDITOR_E3 2
 #define EDITOR_MC 3
 
 #define  CW_SPEEDS	"06121416182022242628303234363840424446485060"
-#endif
 
 #if defined (TLN_LOGLINE)
 /* do nothing, already defined */
@@ -136,3 +135,7 @@ struct tln_logline {
 } ;
 #endif
 
+void refreshp();
+
+#endif /* TLF_H */
+
